# Applications in the Reference Catalog
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#benefits)
  * [Applications in Scope](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#applications-in-scope)
  * [Applications Out of Scope](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#applications-out-of-scope)
  * [Configuring Settings for Syncing Fields and Establishing Relations](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#configuring-settings-for-syncing-fields-and-establishing-relations)
  * [Linking Applications to Catalog Items](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#linking-applications-to-catalog-items)
  * [Bulk Linking Application Fact Sheets](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#bulk-linking-application-fact-sheets)
  * [Ignoring Application Fact Sheets](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog#ignoring-application-fact-sheets)


View all
By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.
